window.Gleam.initSearch([{"doc":"shork","title":"shork","content":"# shork\n\nA MySQL / MariaDB database client for Gleam, based on [MySQL-OTP](https://github.com/mysql-otp/mysql-otp). Heavily inspired by [POG](https://github.com/lpil/pog)\n\n```gleam\nimport shork\n\npub fn main() {  \n  // Start database connection\n  let connection =\n    shork.default_config()\n    |&gt; shork.user(&quot;root&quot;)\n    |&gt; shork.password(&quot;strong_password&quot;)\n    |&gt; shork.database(&quot;poke&quot;)\n    |&gt; shork.connect\n\n  //  A SQL query with one parameter\n  let query = &quot;select name, hp from pokemon where id = ?&quot;\n\n  //  The  decoder for the returned data\n  let row_decoder = {\n    use name &lt;- decode.field(0, decode.name)\n    use hp &lt;- decode.field(1, decode.int)\n\n    decode.success(#(name, hp))\n  }\n\n  // Runs the query\n  // The int 1 is given as parameter\n  let assert Ok(response) = \n    shork.query(query)\n    |&gt; shork.parameter(shork.int(1))\n    |&gt; shork.returning(row_decoder)\n    |&gt; shork.execute(connection)\n\n  response.rows\n  |&gt; should.equal([\n    #(&quot;bulbasaur&quot;, 45)\n  ])\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/shork&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n\n## Acknowlement\n\nThis project is kindly supported by [binary butterfly](https://github.com/binary-butterfly).\n\n## License\n\nGNU Lesser General Public License (LGPL) version 3 or any later version.\nSince the LGPL is a set of additional permissions on top of the GPL, both\nlicense texts are included in the files LICENSE and LICENSE.LESSER respectively.\n\nIn short, LGPL allows you to use the library in non-free software and software\nwith incompatible licenses.\n","url":"index.html"},{"doc":"shork","title":"Config","content":"pub opaque type Config\n The configuration of a connection.\n\nSynonyms:\nshork.Config\nshork Config","url":"shork.html#Config"},{"doc":"shork","title":"Connection","content":"pub type Connection\n\n\nSynonyms:\nshork.Connection\nshork Connection","url":"shork.html#Connection"},{"doc":"shork","title":"Query","content":"pub opaque type Query(row_type)\n\n\nSynonyms:\nshork.Query\nshork Query","url":"shork.html#Query"},{"doc":"shork","title":"QueryError","content":"pub type QueryError {\n  UnexpectedResultType(List(decode.DecodeError))\n  ServerError(Int, String)\n}\n\nUnexpectedResultType(List(decode.DecodeError))\n The rows returned by the database could not be decoded using\n the supplied dynamic decoder.\n\nServerError(Int, String)\n The server returned a error during processing the query.\n\nSynonyms:\nshork.QueryError\nshork QueryError","url":"shork.html#QueryError"},{"doc":"shork","title":"Returend","content":"pub type Returend(t) {\n  Returend(column_names: List(String), rows: List(t))\n}\n The names of the column names and the  rows returend \n by the query.\nReturend(column_names: List(String), rows: List(t))\n\n\nSynonyms:\nshork.Returend\nshork Returend","url":"shork.html#Returend"},{"doc":"shork","title":"TransactionError","content":"pub type TransactionError {\n  TransactionQueryError(QueryError)\n  TransactionRolledBack(String)\n}\n\nTransactionQueryError(QueryError)\n One query inside a query returned a error.\n\nTransactionRolledBack(String)\n The transaction rolled back as an result of an \n error inside the transaction.\n\nSynonyms:\nshork.TransactionError\nshork TransactionError","url":"shork.html#TransactionError"},{"doc":"shork","title":"Value","content":"pub type Value\n A value that can be sent to MySQL as one of the arguments to a\n parameterised SQL query.\n\nSynonyms:\nshork.Value\nshork Value","url":"shork.html#Value"},{"doc":"shork","title":"bool","content":"pub fn bool(a: Bool) -&gt; Value\n\nSynonyms:\nshork.bool\nshork bool","url":"shork.html#bool"},{"doc":"shork","title":"connect","content":"pub fn connect(a: Config) -&gt; Connection\n Starts a database connection.\nSynonyms:\nshork.connect\nshork connect","url":"shork.html#connect"},{"doc":"shork","title":"connection_timeout","content":"pub fn connection_timeout(\n  config: Config,\n  query_timeout: Int,\n) -&gt; Config\n The maximum time to spend on connect.\n \n (default: 3000)\nSynonyms:\nshork.connection_timeout\nshork connection_timeout","url":"shork.html#connection_timeout"},{"doc":"shork","title":"database","content":"pub fn database(config: Config, database: String) -&gt; Config\n Name of the database to use.\nSynonyms:\nshork.database\nshork database","url":"shork.html#database"},{"doc":"shork","title":"default_config","content":"pub fn default_config() -&gt; Config\n The default configuration for a connection. \n\nSynonyms:\nshork.default_config\nshork default_config","url":"shork.html#default_config"},{"doc":"shork","title":"disconnect","content":"pub fn disconnect(a: Connection) -&gt; Nil\n Stops a database connection.\nSynonyms:\nshork.disconnect\nshork disconnect","url":"shork.html#disconnect"},{"doc":"shork","title":"execute","content":"pub fn execute(\n  query: Query(a),\n  connection: Connection,\n) -&gt; Result(Returend(a), QueryError)\n Run a query against a MySQL/MariaDB database.\nSynonyms:\nshork.execute\nshork execute","url":"shork.html#execute"},{"doc":"shork","title":"float","content":"pub fn float(a: Float) -&gt; Value\n\nSynonyms:\nshork.float\nshork float","url":"shork.html#float"},{"doc":"shork","title":"host","content":"pub fn host(config: Config, host: String) -&gt; Config\n Database server hostname.\n \n (default: localhost)\nSynonyms:\nshork.host\nshork host","url":"shork.html#host"},{"doc":"shork","title":"int","content":"pub fn int(a: Int) -&gt; Value\n\nSynonyms:\nshork.int\nshork int","url":"shork.html#int"},{"doc":"shork","title":"keep_alive","content":"pub fn keep_alive(config: Config, keep_alive: Bool) -&gt; Config\n Whether to send keep alive messages for used connections.\n \n (default: False)\nSynonyms:\nshork.keep_alive\nshork keep_alive","url":"shork.html#keep_alive"},{"doc":"shork","title":"log_slow_queries","content":"pub fn log_slow_queries(\n  config: Config,\n  log_slow_queries: Bool,\n) -&gt; Config\n Whether to log queries that got as slow query from the server.\n \n (default: False)\nSynonyms:\nshork.log_slow_queries\nshork log_slow_queries","url":"shork.html#log_slow_queries"},{"doc":"shork","title":"log_warnings","content":"pub fn log_warnings(config: Config, log_warnings: Bool) -&gt; Config\n Whether to fetch warnings and log them using error_logger.\n \n (default: False)\nSynonyms:\nshork.log_warnings\nshork log_warnings","url":"shork.html#log_warnings"},{"doc":"shork","title":"parameter","content":"pub fn parameter(query: Query(a), parameter: Value) -&gt; Query(a)\n Push a new parameter value for the query.\nSynonyms:\nshork.parameter\nshork parameter","url":"shork.html#parameter"},{"doc":"shork","title":"password","content":"pub fn password(config: Config, password: String) -&gt; Config\n Password for the user.\nSynonyms:\nshork.password\nshork password","url":"shork.html#password"},{"doc":"shork","title":"port","content":"pub fn port(config: Config, port: Int) -&gt; Config\n Port the server is listing on.\n \n (default: 3306)\nSynonyms:\nshork.port\nshork port","url":"shork.html#port"},{"doc":"shork","title":"query","content":"pub fn query(sql: String) -&gt; Query(Nil)\n Set the decoder to use for the type of row returned by executing this query.\n \n If the decoder is unable to decode the row value then query will return an \n error. \nSynonyms:\nshork.query\nshork query","url":"shork.html#query"},{"doc":"shork","title":"query_cache_time","content":"pub fn query_cache_time(\n  config: Config,\n  query_cache_time: Int,\n) -&gt; Config\n The minimum number of milliseconds to cache prepared statements used\n for parametrized queries with query.\n \n (default: 1000)\nSynonyms:\nshork.query_cache_time\nshork query_cache_time","url":"shork.html#query_cache_time"},{"doc":"shork","title":"query_timeout","content":"pub fn query_timeout(\n  config: Config,\n  query_timeout: Int,\n) -&gt; Config\n Default time to wait for a query to execute.\n \n (default: 5000)\nSynonyms:\nshork.query_timeout\nshork query_timeout","url":"shork.html#query_timeout"},{"doc":"shork","title":"returning","content":"pub fn returning(\n  query: Query(a),\n  decoder: Decoder(b),\n) -&gt; Query(b)\n Create a new query to use with the `execute`, `returning` and `parameters`\n function.\n\nSynonyms:\nshork.returning\nshork returning","url":"shork.html#returning"},{"doc":"shork","title":"text","content":"pub fn text(a: String) -&gt; Value\n\nSynonyms:\nshork.text\nshork text","url":"shork.html#text"},{"doc":"shork","title":"timeout","content":"pub fn timeout(query: Query(a), timeout: Int) -&gt; Query(a)\n Use a custom timeout for the query.\n The timeout give is given in ms.\nSynonyms:\nshork.timeout\nshork timeout","url":"shork.html#timeout"},{"doc":"shork","title":"transaction","content":"pub fn transaction(\n  connection: Connection,\n  callback cb: fn(Connection) -&gt; Result(a, b),\n) -&gt; Result(a, TransactionError)\n\nSynonyms:\nshork.transaction\nshork transaction","url":"shork.html#transaction"},{"doc":"shork","title":"user","content":"pub fn user(config: Config, user: String) -&gt; Config\n Username to connect to database as.\nSynonyms:\nshork.user\nshork user","url":"shork.html#user"},{"doc":"shork","title":"shork","content":"","url":"shork.html"}]);